diff --git a/README b/README
index a09809c..810806f 100644
--- a/README
+++ b/README
@@ -1,8 +1,7 @@
+To setup a local instance of pandora:
-To setup a local instance of 0xdb:
-
- bzr branch http://code.0xdb.org/oxdb2 oxdb
- cd oxdb
+ bzr branch http://code.0xdb.org/pandora pandora
+ cd pandora
virtualenv .
pip -E . install -r requirements.txt
@@ -17,13 +16,12 @@ also it uses system python moduels, so make sure you have
ipython, dbmodule(psycopg2, python-mysqldb,..)
installed via apt-get/pip/easy_install in your system path.
-
Install rabbitmq and carrot:
sudo apt-get install rabbitmq-server
- sudo rabbitmqctl add_user oxdb password
- sudo rabbitmqctl add_vhost /oxdb
- sudo rabbitmqctl set_permissions -p /oxdb oxdb "^oxdb-.*" ".*" ".*"
+ sudo rabbitmqctl add_user pandora password
+ sudo rabbitmqctl add_vhost /pandora
+ sudo rabbitmqctl set_permissions -p /pandora pandora "^pandora-.*" ".*" ".*"
update BROKER_* settings in local_settings.py:
@@ -32,5 +30,3 @@ Development:
we are using django, http://docs.djangoproject.com/en/dev/
communication between webserver and background tasks is done via rabbitmq
http://github.com/ask/carrot/ for more info on the lib used to communicate
-
-
diff --git a/oxdb/__init__.py b/pandora/__init__.py
similarity index 100%
rename from oxdb/__init__.py
rename to pandora/__init__.py
diff --git a/oxdb/app/__init__.py b/pandora/app/__init__.py
similarity index 100%
rename from oxdb/app/__init__.py
rename to pandora/app/__init__.py
diff --git a/pandora/app/admin.py b/pandora/app/admin.py
new file mode 100644
index 0000000..1352195
--- /dev/null
+++ b/pandora/app/admin.py
@@ -0,0 +1,12 @@
+# -*- coding: utf-8 -*-
+# vi:si:et:sw=4:sts=4:ts=4
+
+from django.contrib import admin
+
+import models
+
+
+class PageAdmin(admin.ModelAdmin):
+ search_fields = ['name', 'body']
+
+admin.site.register(models.Page, PageAdmin)
diff --git a/oxdb/app/models.py b/pandora/app/models.py
similarity index 100%
rename from oxdb/app/models.py
rename to pandora/app/models.py
diff --git a/oxdb/app/tests.py b/pandora/app/tests.py
similarity index 100%
rename from oxdb/app/tests.py
rename to pandora/app/tests.py
diff --git a/oxdb/app/views.py b/pandora/app/views.py
similarity index 100%
rename from oxdb/app/views.py
rename to pandora/app/views.py
diff --git a/oxdb/backend/__init__.py b/pandora/backend/__init__.py
similarity index 100%
rename from oxdb/backend/__init__.py
rename to pandora/backend/__init__.py
diff --git a/oxdb/backend/admin.py b/pandora/backend/admin.py
similarity index 100%
rename from oxdb/backend/admin.py
rename to pandora/backend/admin.py
diff --git a/oxdb/backend/daemon.py b/pandora/backend/daemon.py
similarity index 100%
rename from oxdb/backend/daemon.py
rename to pandora/backend/daemon.py
diff --git a/oxdb/backend/encoder.py b/pandora/backend/encoder.py
similarity index 100%
rename from oxdb/backend/encoder.py
rename to pandora/backend/encoder.py
diff --git a/oxdb/backend/extract.py b/pandora/backend/extract.py
similarity index 100%
rename from oxdb/backend/extract.py
rename to pandora/backend/extract.py
diff --git a/oxdb/backend/forms.py b/pandora/backend/forms.py
similarity index 100%
rename from oxdb/backend/forms.py
rename to pandora/backend/forms.py
diff --git a/oxdb/backend/load.py b/pandora/backend/load.py
similarity index 100%
rename from oxdb/backend/load.py
rename to pandora/backend/load.py
diff --git a/oxdb/backend/management/__init__.py b/pandora/backend/management/__init__.py
similarity index 100%
rename from oxdb/backend/management/__init__.py
rename to pandora/backend/management/__init__.py
diff --git a/oxdb/backend/management/commands/__init__.py b/pandora/backend/management/commands/__init__.py
similarity index 100%
rename from oxdb/backend/management/commands/__init__.py
rename to pandora/backend/management/commands/__init__.py
diff --git a/oxdb/backend/management/commands/backgroundtasks.py b/pandora/backend/management/commands/backgroundtasks.py
similarity index 100%
rename from oxdb/backend/management/commands/backgroundtasks.py
rename to pandora/backend/management/commands/backgroundtasks.py
diff --git a/oxdb/backend/management/commands/encoder.py b/pandora/backend/management/commands/encoder.py
similarity index 100%
rename from oxdb/backend/management/commands/encoder.py
rename to pandora/backend/management/commands/encoder.py
diff --git a/oxdb/backend/managers.py b/pandora/backend/managers.py
similarity index 100%
rename from oxdb/backend/managers.py
rename to pandora/backend/managers.py
diff --git a/oxdb/backend/migrations/__init__.py b/pandora/backend/migrations/__init__.py
similarity index 100%
rename from oxdb/backend/migrations/__init__.py
rename to pandora/backend/migrations/__init__.py
diff --git a/oxdb/backend/models.py b/pandora/backend/models.py
similarity index 100%
rename from oxdb/backend/models.py
rename to pandora/backend/models.py
diff --git a/oxdb/backend/urls.py b/pandora/backend/urls.py
similarity index 100%
rename from oxdb/backend/urls.py
rename to pandora/backend/urls.py
diff --git a/oxdb/backend/utils.py b/pandora/backend/utils.py
similarity index 100%
rename from oxdb/backend/utils.py
rename to pandora/backend/utils.py
diff --git a/oxdb/backend/views.py b/pandora/backend/views.py
similarity index 99%
rename from oxdb/backend/views.py
rename to pandora/backend/views.py
index 98229eb..8e30cff 100644
--- a/oxdb/backend/views.py
+++ b/pandora/backend/views.py
@@ -701,5 +701,6 @@ def apidoc(request):
'name': f[4:],
'doc': trim(globals()[f].__doc__).replace('\n', '
\n')
})
- context = RequestContext(request, {'api': api})
+ context = RequestContext(request, {'api': api,
+ 'sitename': settings.SITENAME,})
return render_to_response('api.html', context)
diff --git a/oxdb/static/css/ui.css b/pandora/static/css/ui.css
similarity index 100%
rename from oxdb/static/css/ui.css
rename to pandora/static/css/ui.css
diff --git a/oxdb/static/jquery b/pandora/static/jquery
similarity index 100%
rename from oxdb/static/jquery
rename to pandora/static/jquery
diff --git a/oxdb/static/js/ajax_filtered_fields.js b/pandora/static/js/ajax_filtered_fields.js
similarity index 100%
rename from oxdb/static/js/ajax_filtered_fields.js
rename to pandora/static/js/ajax_filtered_fields.js
diff --git a/oxdb/static/js/jquery/jquery.js b/pandora/static/js/jquery/jquery.js
similarity index 100%
rename from oxdb/static/js/jquery/jquery.js
rename to pandora/static/js/jquery/jquery.js
diff --git a/oxdb/static/js/ui.js b/pandora/static/js/ui.js
similarity index 100%
rename from oxdb/static/js/ui.js
rename to pandora/static/js/ui.js
diff --git a/oxdb/static/png/frame.png b/pandora/static/png/frame.png
similarity index 100%
rename from oxdb/static/png/frame.png
rename to pandora/static/png/frame.png
diff --git a/oxdb/static/png/timeline.png b/pandora/static/png/timeline.png
similarity index 100%
rename from oxdb/static/png/timeline.png
rename to pandora/static/png/timeline.png
diff --git a/oxdb/templates/404.html b/pandora/templates/404.html
similarity index 100%
rename from oxdb/templates/404.html
rename to pandora/templates/404.html
diff --git a/oxdb/templates/500.html b/pandora/templates/500.html
similarity index 100%
rename from oxdb/templates/500.html
rename to pandora/templates/500.html
diff --git a/oxdb/templates/admin/base_site.html b/pandora/templates/admin/base_site.html
similarity index 100%
rename from oxdb/templates/admin/base_site.html
rename to pandora/templates/admin/base_site.html
diff --git a/oxdb/templates/api.html b/pandora/templates/api.html
similarity index 70%
rename from oxdb/templates/api.html
rename to pandora/templates/api.html
index df93ad6..83e1d97 100644
--- a/oxdb/templates/api.html
+++ b/pandora/templates/api.html
@@ -1,13 +1,13 @@
diff --git a/oxdb/manage.py b/pandora/manage.py
similarity index 100%
rename from oxdb/manage.py
rename to pandora/manage.py
diff --git a/oxdb/oxuser/__init__.py b/pandora/oxuser/__init__.py
similarity index 100%
rename from oxdb/oxuser/__init__.py
rename to pandora/oxuser/__init__.py
diff --git a/oxdb/oxuser/models.py b/pandora/oxuser/models.py
similarity index 100%
rename from oxdb/oxuser/models.py
rename to pandora/oxuser/models.py
diff --git a/oxdb/oxuser/templates/recover_email.txt b/pandora/oxuser/templates/recover_email.txt
similarity index 100%
rename from oxdb/oxuser/templates/recover_email.txt
rename to pandora/oxuser/templates/recover_email.txt
diff --git a/oxdb/oxuser/tests.py b/pandora/oxuser/tests.py
similarity index 100%
rename from oxdb/oxuser/tests.py
rename to pandora/oxuser/tests.py
diff --git a/oxdb/oxuser/urls.py b/pandora/oxuser/urls.py
similarity index 100%
rename from oxdb/oxuser/urls.py
rename to pandora/oxuser/urls.py
diff --git a/oxdb/oxuser/views.py b/pandora/oxuser/views.py
similarity index 100%
rename from oxdb/oxuser/views.py
rename to pandora/oxuser/views.py
diff --git a/oxdb/settings.py b/pandora/settings.py
similarity index 95%
rename from oxdb/settings.py
rename to pandora/settings.py
index 3c39c06..8c7ea24 100644
--- a/oxdb/settings.py
+++ b/pandora/settings.py
@@ -1,11 +1,11 @@
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4
# Django settings for oxdb project.
import os
from os.path import join
-SITENAME = 'Oxdb'
-URL = 'Oxdb.org'
+SITENAME = 'Pandora'
+URL = 'pandora.Oxdb.org'
PROJECT_ROOT = os.path.normpath(os.path.dirname(__file__))
@@ -33,9 +33,9 @@ DATABASE_PORT = '' # Set to empty string for default. Not used with
#rabbitmq connection settings
BROKER_HOST = "127.0.0.1"
BROKER_PORT = 5672
-BROKER_USER = "oxdb"
-BROKER_PASSWORD = "0xdb"
-BROKER_VHOST = "/oxdb"
+BROKER_USER = "pandora"
+BROKER_PASSWORD = "box"
+BROKER_VHOST = "/pandora"
# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
@@ -88,7 +88,7 @@ MIDDLEWARE_CLASSES = (
'oxdjango.middleware.ExceptionMiddleware',
)
-ROOT_URLCONF = 'oxdb.urls'
+ROOT_URLCONF = 'pandora.urls'
TEMPLATE_DIRS = (
join(PROJECT_ROOT, 'templates'),
@@ -1,11 +1,11 @@
# -*- coding: utf-8 -*-
# vi:si:et:sw=4:sts=4:ts=4
-# Django settings for oxdb project.
+# Django settings for pandora project.
import os
from os.path import join